gokrazyclient

package module
v0.0.0-...-7658a09 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Oct 9, 2024 License: GPL-3.0 Imports: 6 Imported by: 0

README

Go Report Card

Gokrazy-client

Attempt at making a Gokrazy client for use by Terraform plugin

Similar to the hashicups client used for the Terraform provider tutorial this should provide a way for Terraform plugins to interact with deployed devices

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Client

type Client struct {
	InstanceName string
	ParentDir    string

	Conf gokrazyConfiguration
	// contains filtered or unexported fields
}

func NewClient

func NewClient(instanceName string, stdin io.Reader, stdout, stderr io.Writer) (*Client, error)

func (*Client) ApplyConfiguration

func (c *Client) ApplyConfiguration() error

func (*Client) Cleanup

func (c *Client) Cleanup() error

func (*Client) DoRequest

func (c *Client) DoRequest(args []string) error

func (*Client) Update

func (c *Client) Update() error

Jump to